# Unified Crypto Exchange API

| Exchange | Adapter | Client | AioClient | UniClient | WebsocketManager | UniWebsocketManager | AioWebsocketManager | UniAioWebsocketManager |
|----------|---------|--------|-----------|------------|------------------|---------------------|---------------------|------------------------|
| Binance  | [х]     | [x]    | [x]       | [x]        | [x]              | [x]                 | [ ]                 | [ ]                    |
| Bybit    | [ ]     | [ ]    | [ ]       | [ ]        | [ ]              | [ ]                 | [ ]                 | [ ]                    |
| Bitget   | [ ]     | [ ]    | [ ]       | [ ]        | [ ]              | [ ]                 | [ ]                 | [ ]                    |
| Okx      | [ ]     | [ ]    | [ ]       | [ ]        | [ ]              | [ ]                 | [ ]                 | [ ]                    |
| Mexc     | [ ]     | [ ]    | [ ]       | [ ]        | [ ]              | [ ]                 | [ ]                 | [ ]                    |
| Gate     | [ ]     | [ ]    | [ ]       | [ ]        | [ ]              | [ ]                 | [ ]                 | [ ]                    |

# 😔 Проблемы в коде:
- Спот вебсокет на бинансе может отключиться и не переподключиться, потому что renew_listen_key не дает информации о том, когда ключ просрочен.

# todo
- Добавить открытый интерес в клиента
- Добавить веса и рейт лимиты в документацию клиентов
- Привести в порядок обработку ответа после запроса
- Отрефакторить sync user websocket binance

# todo 21 sept
- доделать no_message_reconnect_timeout
